@@ -1,5 +1,5 @@
-"""A handy python function to parse and convert to and between datetime.datetime, int, and string objects"""
-__version__ = "1.2"
+"""One friendly python function for parsing and converting to and between datetime.datetime, int, and string objects"""
+__version__ = "1.2.1"
 
 import math
 import datetime as dt
@@ -8,13 +8,12 @@ from dateparser.timezone_parser import pop_tz_offset_from_string as tz_parse
 
 
 DateTypes = str | int | float | dt.datetime | dt.date
+TIMESTAMP_DIGITS = 10
 ACCEPTED_STRINGS = {
     "str": ["str", "string", "text", ],
-    "date": ["datetime.datetime", "datetime", "date", "dt", "dt.datetime", "dt.date", ],
     "int": ["int", "timestamp", "epoch", "unix", "float", ],
+    "date": ["datetime.datetime", "datetime", "date", "dt", "dt.datetime", "dt.date", ],
 }
-
-TIMESTAMP_DIGITS = 10
 DEFAULT_SETTINGS = {
     "TO_TIMEZONE": "UTC",
     "PREFER_DAY_OF_MONTH": "first",
@@ -22,35 +21,35 @@ DEFAULT_SETTINGS = {
 }
 
 
-def date_to(your_date: DateTypes, /, end_type: DateTypes = dt.datetime,  
+def date_to(your_date: DateTypes, /, to_type: DateTypes = dt.datetime,  
             timezone: str = None, *, parser_settings: dict = None,
             ) -> DateTypes:
     """
     :param your_date: Requires to be either int, float, str, or datetime.date
-    :param end_type: The type you want the date to be converted into
+    :param to_type: The type you want the date to be converted into
     :param timezone: Three letter abbreviation (case insensitive) of desired output timezone. Default is "UTC"
     :param parser_settings: dict of keyword arguments for overriding default dateparser.parse() settings
-    :return: converted time to specified Type[end_type] rounded to seconds
+    :return: converted time to specified Type[to_type] rounded to seconds
     """
     
-    end_type = _validate_end_type(end_type)
+    to_type = _validate_to_type(to_type)
     settings = _parse_settings(timezone, parser_settings)
     if isinstance(your_date, (int, float)):
         your_date = _round_timestamp_to_seconds(your_date)
 
 
-    if end_type == dt.datetime:
+    if to_type == dt.datetime:
         if isinstance(your_date, str):
             return _str_to_datetime(your_date, settings)
         return _to_datetime(your_date, timezone)
 
-    elif end_type == int or end_type == float:
+    elif to_type == int:
         if isinstance(your_date, str):
             return _string_date_to_timestamp(your_date, settings)
         elif isinstance(your_date, dt.datetime):
             return _date_time_to_timestamp(your_date)
 
-    elif end_type == str:
+    elif to_type == str:
         if isinstance(your_date, str):
             # This operation completes a possibly incomplete query_string to seconds
             your_date = _str_to_datetime(your_date, settings)
@@ -92,6 +91,31 @@ def _string_date_to_timestamp(_date_string: str, settings: dict) -> int:
 
 # =====================================
 
+def _validate_to_type(to_type):
+    
+    if to_type == float:
+        to_type = int
+    elif to_type == dt.date:
+        to_type = dt.datetime
+    
+    if isinstance(to_type, str):
+        if to_type.lower() in ACCEPTED_STRINGS["str"]:
+            to_type = str
+        elif to_type.lower() in ACCEPTED_STRINGS["date"]:
+            to_type = dt.datetime
+        elif to_type.lower() in ACCEPTED_STRINGS["int"]:
+            to_type = int
+        else:
+            raise KeyError(f"Invalid input string: {to_type=}"
+                           f"Accepted string representations are: {ACCEPTED_STRINGS}")
+            
+    elif to_type != str and to_type != int and to_type != dt.datetime:
+        raise TypeError(f"Invalid input {to_type=} given. \n"
+                        f"The only date input types allowed are {DateTypes} either as an object or in string representation.")
+
+    return to_type
+
+
 def _parse_settings(timezone: str = None, parser_settings: dict = None) -> dict:
         settings = parser_settings if parser_settings else DEFAULT_SETTINGS
         if timezone:
@@ -99,7 +123,7 @@ def _parse_settings(timezone: str = None, parser_settings: dict = None) -> dict:
         return settings
 
 
-def _round_timestamp_to_seconds(_timestamp: int | float) -> int:  # Assumes positive number
+def _round_timestamp_to_seconds(_timestamp: int | float) -> int:
     if _timestamp < 0:
         raise DateInputError(f"Input timestamp {_timestamp} is invalid (negative number)")
     
@@ -110,33 +134,7 @@ def _round_timestamp_to_seconds(_timestamp: int | float) -> int:  # Assumes posi
         _timestamp //= 10**decimal
     return int(_timestamp)
 
-
+# =====================================
 class DateInputError(Exception):
     pass
 
-
-def _validate_end_type(end_type):
-    
-    if end_type == float:
-        end_type = int
-    elif end_type == dt.date:
-        end_type = dt.datetime
-    
-    if isinstance(end_type, str):
-        if end_type.lower() in ACCEPTED_STRINGS["str"]:
-            end_type = str
-        elif end_type.lower() in ACCEPTED_STRINGS["date"]:
-            end_type = dt.datetime
-        elif end_type.lower() in ACCEPTED_STRINGS["int"]:
-            end_type = int
-        else:
-            raise KeyError(
-                f"Invalid input string: {end_type=}"
-                f"Accepted string representations are: {ACCEPTED_STRINGS}"
-            )
-            
-    elif end_type != str and end_type != int and end_type != dt.datetime:
-        raise TypeError(f"Invalid input {end_type=} given. \n"
-                        f"The only date input types allowed are {DateTypes} either as an object or in string representation.")
-
-    return end_type
